@@ -234,13 +234,11 @@ def bazos_one_word(exp, blacklist, wordcore, word_decl, word_decl_re):
                     '''
 
                     url = anno.a["href"]
-                    # idpool = re.search('\/inzerat(.+?)\/', str(url))
-                    idpool = re.search('/inzerat(.+?)/', str(url))
+                    idpool = re.search('\/inzerat(.+?)\/', str(url))
                     identifier = idpool.group(
                         1)  # id pro bazoš začíná lomítkem - možno odlišit příp. jinak, ale je to nutné - má taky 9místná čísla jako Sbazar, může se pomlátit, už se mi to v jednom případě stalo
                     datepool = anno.find("span", {'class', 'velikost10'})
-                    # datepool2 = re.search('\[(.+?)\]', str(datepool))
-                    datepool2 = re.search('[(.+?)]', str(datepool))
+                    datepool2 = re.search('\[(.+?)\]', str(datepool))
                     if datepool2:
                         date = datepool2.group(1)
                     else:
@@ -267,8 +265,7 @@ def bazos_one_word(exp, blacklist, wordcore, word_decl, word_decl_re):
                         if "google.com/maps" in str(x):
                             map_link = x["href"]
 
-                    # coordinates_str = re.search('google.com\/maps\/place\/(.*)\/@', map_link)
-                    coordinates_str = re.search('google.com/maps/place/(.*)/@', map_link)
+                    coordinates_str = re.search('google.com\/maps\/place\/(.*)\/@', map_link)
                     c = coordinates_str.group(1)
                     lat = float(c.split(",")[0])
                     lon = float(c.split(",")[1])
